Slider Example
===============================================================================

:download:`slider.enaml <../../../examples/components/slider.enaml>`

.. literalinclude:: ../../../examples/components/slider.enaml
    :language: python

::

 $ enaml-run slider.enaml

.. image:: images/slider.png
